@@ -1,19 +1,19 @@
 
-#define HOST_CPU "i486"
+#define HOST_CPU "i686"
 #define HOST_VENDOR "pc"
 #define HOST_OS "linux"
 #define HOST_OS_NAME "linux"
-#define HOST_OS_VERSION "2.2.10"
+#define HOST_OS_VERSION "2.2.16-1cucs"
 #define HOST_ARCH "i386"
-#define HOST_NAME "holstein.cs.columbia.edu"
+#define HOST_NAME "earth.cs.columbia.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Tue Jul  4 18:14:42 EDT 2000"
+#define CONFIG_DATE "Sun Jun 11 02:49:53 EDT 2000"
 #define PACKAGE "am-utils"
-#define VERSION "6.0.4s6"
+#define VERSION "6.1a2"
 #define PACKAGE "am-utils"
-#define VERSION "6.0.4s6"
+#define VERSION "6.1a2"
 #define DEBUG 1
-#define HOST_HEADER_VERSION "2.2.5-22"
+#define HOST_HEADER_VERSION "2.2.14-3cucs"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_LIBNSL 1
@@ -173,6 +173,7 @@
 #define HAVE_MALLOC_H 1
 #define HAVE_MEMORY_H 1
 #define HAVE_MNTENT_H 1
+#define HAVE_NDBM_H 1
 #define HAVE_NETDB_H 1
 #define HAVE_PWD_H 1
 #define HAVE_REGEX_H 1
@@ -247,10 +248,13 @@
 #define HAVE_MAP_NISPLUS 1
 #define HAVE_MAP_PASSWD 1
 #define HAVE_MAP_UNION 1
+#define HAVE_FS_AUTOFS 1
 #define HAVE_FS_CDFS 1
 #define HAVE_FS_NFS 1
+#define HAVE_FS_NFS3 1
 #define HAVE_FS_PCFS 1
 #define HAVE_FS_UFS 1
+#define HAVE_FS_EFS 1
 #define HAVE_AMU_FS_AUTO 1
 #define HAVE_AMU_FS_DIRECT 1
 #define HAVE_AMU_FS_TOPLVL 1
@@ -264,15 +268,20 @@
 #define HAVE_AMU_FS_NFSL 1
 #define HAVE_AMU_FS_UNION 1
 #define MOUNT_TYPE_NFS MNTTYPE_NFS
+#define MOUNT_TYPE_NFS3 MNTTYPE_NFS3
 #define MOUNT_TYPE_UFS "ext2"
-#define MOUNT_TYPE_CDFS "iso9660"
+#define MOUNT_TYPE_EFS "efs"
+#define MOUNT_TYPE_CDFS MNTTYPE_ISO9660
 #define MOUNT_TYPE_PCFS "vfat"
+#define MOUNT_TYPE_AUTOFS "autofs"
 #define MOUNT_TYPE_IGNORE MNTTYPE_IGNORE
 #define MNTTAB_TYPE_NFS "nfs"
 #define MNTTAB_TYPE_NFS3 "nfs"
 #define MNTTAB_TYPE_UFS "ext2"
+#define MNTTAB_TYPE_EFS "efs"
 #define MNTTAB_TYPE_CDFS "iso9660"
 #define MNTTAB_TYPE_PCFS "vfat"
+#define MNTTAB_TYPE_AUTOFS "autofs"
 #define MNTTAB_OPT_NOAUTO "noauto"
 #define MNTTAB_OPT_NOSUID "nosuid"
 #define MNTTAB_OPT_RO "ro"
